@@ -138,6 +138,9 @@ class Chartsheet(worksheet.Worksheet):
         # Write the drawing element.
         self._write_drawings()
 
+        # Write the legacyDrawingHF element.
+        self._write_legacy_drawing_hf()
+
         # Close the worksheet tag.
         self._xml_end_tag("chartsheet")
 
